![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/Graph3x/dbtogo/ci.yml)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dbtogo)
![PyPI - Downloads](https://img.shields.io/pypi/dm/dbtogo)


# DBTOGO

dbtogo is a simple work-in-progress ORM library for Python3. Its goal is to emulate the style libraries like peewee use (maximal abstraction and simplicity) while being build on top of Pydantic models for simple integration with FastAPI and others.

dbtogo is aimed at smaller projects that do not require optimization. I am making this primarily to learn more about ORMs, so this should not be used in any serious production code.